from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Directory, Int, Boolean, Float, File, String

Spamo_V0_1_0 = CommandToolBuilder(tool="spamo", base_command=["spamo"], inputs=[ToolInput(tag="in_create_directory_write", input_type=Directory(optional=True), prefix="-o", doc=InputDocumentation(doc="create the directory and write output files in it;\nnot compatible with -oc")), ToolInput(tag="in_oc", input_type=Directory(optional=True), prefix="-oc", doc=InputDocumentation(doc="create the directory but if it already exists allow\noverwriting the contents; default: spamo_out")), ToolInput(tag="in_min_score", input_type=Int(optional=True), prefix="-minscore", doc=InputDocumentation(doc="the minimum score (bits) to accept as a motif match;\ndefault: 7\nNote: if <valu> is in the range [-1, 0), then the\nminimum score is set to: -<valu>*pwm_maximum_score")), ToolInput(tag="in_margin", input_type=Int(optional=True), prefix="-margin", doc=InputDocumentation(doc="edge margin excluded for primary motif matches and\nthe maximum distance from the primary motif to the\nsecondary motif; default: 150")), ToolInput(tag="in_bin", input_type=Int(optional=True), prefix="-bin", doc=InputDocumentation(doc="size of bins used for output; default: 1")), ToolInput(tag="in_range", input_type=Int(optional=True), prefix="-range", doc=InputDocumentation(doc="the range from the primary to include in significance\ntests; default: 150")), ToolInput(tag="in_use_best_sec", input_type=Boolean(optional=True), prefix="-usebestsec", doc=InputDocumentation(doc="use only the best match of the secondary motif;\ndefault: count all secondary matches above the\nscore match threshold in the margins around the\nprimary motif match")), ToolInput(tag="in_shared", input_type=Float(optional=True), prefix="-shared", doc=InputDocumentation(doc="fraction of shared trimmed sequence content that\nis required to exclude the sequence as redundant;\nset <fract> to 0 to skip sequence redundancy check;\ndefault: 0.5")), ToolInput(tag="in_odds", input_type=Int(optional=True), prefix="-odds", doc=InputDocumentation(doc="odds ratio used for speedup of the redundant\nsequence check; low values may cause some\nredundant sequences to be missed; set <odds>\nto 0 to do full-length check;\ndefault: 20")), ToolInput(tag="in_cut_off", input_type=Float(optional=True), prefix="-cutoff", doc=InputDocumentation(doc="cutoff for spacings to be considered significant;\ndefault: 0.05")), ToolInput(tag="in_evalue", input_type=Int(optional=True), prefix="-evalue", doc=InputDocumentation(doc="minimum E-value for printing secondary motifs;\ndefault: 10")), ToolInput(tag="in_overlap", input_type=Int(optional=True), prefix="-overlap", doc=InputDocumentation(doc="number of bases that the most significant spacing\nmust overlap before further redundancy testing is\ndone; default: 2")), ToolInput(tag="in_joint", input_type=Float(optional=True), prefix="-joint", doc=InputDocumentation(doc="fraction of sites making up the most significant\nspacing that must be in both sets for the less\nsignificant motif to be considered redundant;\ndefault: 0.5")), ToolInput(tag="in_pseudo", input_type=Float(optional=True), prefix="-pseudo", doc=InputDocumentation(doc="pseudocount added to loaded motifs;\ndefault: 0.1")), ToolInput(tag="in_bg_file", input_type=File(optional=True), prefix="-bgfile", doc=InputDocumentation(doc="file containing background frequency information\nused to apply pseudocounts to motifs and create the\nscoring matrices; default: calculate from sequences")), ToolInput(tag="in_x_alph", input_type=Boolean(optional=True), prefix="-xalph", doc=InputDocumentation(doc="Convert the alphabet of the secondary motif databases\nto the alphabet of the primary motif\nassuming the core symbols of the secondary motif\nalphabet are a subset; default: reject differences")), ToolInput(tag="in_trim", input_type=Float(optional=True), prefix="-trim", doc=InputDocumentation(doc="trim the edges of motifs based on the information\ncontent; positions on the edges with information\ncontent less than bits will not be used in\nscanning\ndefault: 0.25")), ToolInput(tag="in_num_gen", input_type=Int(optional=True), prefix="-numgen", doc=InputDocumentation(doc="specify the random seed for initializing the pseudo-\nrandom number generator used in breaking ties;\nthe seed is included in the output so experiments\ncan be repeated; special value 'time' seeds to the\nsystem clock; default: 1")), ToolInput(tag="in_primary", input_type=String(optional=True), prefix="-primary", doc=InputDocumentation(doc="name of motif to select as the primary motif;\noverrides -primaryi")), ToolInput(tag="in_primary_i", input_type=Int(optional=True), prefix="-primaryi", doc=InputDocumentation(doc="index of motif to select as the primary motif\ncounting from 1; default: 1")), ToolInput(tag="in_keep_primary", input_type=Boolean(optional=True), prefix="-keepprimary", doc=InputDocumentation(doc="by default all occurrences of the primary other\nthan the chosen one are erased to reduce the\nnumber of motifs whose apparent enrichment is due\nto multiple occurrences of the primary motif. If\nthe same file is specified for the primary and\nsecondary motifs, then this option will override\nerasing and primary-primary spacings will be\nanalyzed.")), ToolInput(tag="in_inc", input_type=String(optional=True), prefix="-inc", doc=InputDocumentation(doc="name pattern to select as secondary motif; may be\nrepeated; default: all motifs are used")), ToolInput(tag="in_exc", input_type=String(optional=True), prefix="-exc", doc=InputDocumentation(doc="name pattern to exclude as secondary motif; may be\nrepeated; default: all motifs are used")), ToolInput(tag="in_text", input_type=File(optional=True), prefix="-text", doc=InputDocumentation(doc="output text file only (no HTML or XML)")), ToolInput(tag="in_eps", input_type=Boolean(optional=True), prefix="-eps", doc=InputDocumentation(doc="output histograms in eps format; usable with -png")), ToolInput(tag="in_png", input_type=Boolean(optional=True), prefix="-png", doc=InputDocumentation(doc="output histograms in png format; usable with -eps")), ToolInput(tag="in_dumps_eqs", input_type=Boolean(optional=True), prefix="-dumpseqs", doc=InputDocumentation(doc="dump matching trimmed sequences to output files;\nmatches are initially in sequence name order;\nsee documentation for column descriptions")), ToolInput(tag="in_dump_sigs", input_type=Boolean(optional=True), prefix="-dumpsigs", doc=InputDocumentation(doc="same as above except only secondary matches in\nin significant bins are dumped\nmatches are initially in sequence name order;\nsee documentation for column descriptions")), ToolInput(tag="in_verbosity", input_type=Int(optional=True), prefix="-verbosity", doc=InputDocumentation(doc="set the verbosity of the output: 1 (quiet) - 5 (dump);\ndefault: 2 (normal)")), ToolInput(tag="in_version", input_type=Boolean(optional=True), prefix="-version", doc=InputDocumentation(doc="print the version and exit")), ToolInput(tag="in_sequences", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_primary_motif", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_secondary_motifs", input_type=String(), position=2, doc=InputDocumentation(doc=""))], outputs=[ToolOutput(tag="out_create_directory_write", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_create_directory_write", type_hint=File()), doc=OutputDocumentation(doc="create the directory and write output files in it;\nnot compatible with -oc")), ToolOutput(tag="out_text", output_type=File(optional=True), selector=InputSelector(input_to_select="in_text", type_hint=File()), doc=OutputDocumentation(doc="output text file only (no HTML or XML)"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Spamo_V0_1_0().translate("wdl", allow_empty_container=True)

